# dcurves

Dcurves is a Python library for Andrew Vickers' Decision Curve Analysis method to evaluate prediction models and diagnostic tests. 


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install dcurves.

```bash
pip install dcurves
```
## Usage

```python
import dcurves
```
## Usage: 
## Please refer to https://www.danieldsjoberg.com/dca-tutorial/dca-tutorial-r.html
## NOTE: Please wait for python snippets to be updated (Coming Extremely Soon!)


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[Apache 2.0]([https://choosealicense.com/licenses/apache-2.0/])
